@@ -1,12 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "pi-coding-agent" "1.3.6"
+(define-package "pi-coding-agent" "20260117.2159"
   "Emacs frontend for pi coding agent."
   '((emacs         "28.1")
-    (markdown-mode "2.6")
-    (transient     "0.9.0"))
-  :url "https://github.com/dnouri/pi-coding-agent"
-  :commit "13c5b10f28137663e98386c6c7299f445d04b87a"
-  :revdesc "v1.3.6-0-g13c5b10f2813"
+    (markdown-mode "2.6"))
+  :url "https://github.com/dnouri/pi.el"
+  :commit "b734fe0b2007126bf2c33bf0ef7cb1c45d8bd365"
+  :revdesc "b734fe0b2007"
   :keywords '("ai" "llm" "ai-pair-programming" "tools")
   :authors '(("Daniel Nouri" . "daniel.nouri@gmail.com"))
   :maintainers '(("Daniel Nouri" . "daniel.nouri@gmail.com")))
